# paynspray
The Pay 'n' Spray library provides access to functions pertaining to text generation, manipulation, &amp; presentation.

## Installation

You can install Pay 'n' Spray using the Python package installer (pip).

Run the following command:

    $ pip install paynspray
